import os


def rename(oldname,newname):
	if os.path.exists(oldname):
		os.rename(oldname,newname)
		print('File {} Renamed to {}'.format(oldname,newname))
	else:
		print('File Not Found')

def create(name,cont,mode='w'):

	with open(name,mode) as f:
		f.write(cont)
	f.close()

	print('File {} created'.format(name))


def delete(name):
	if os.path.exists(name):
		os.remove(name)
	else:
		print('File not found please provide full path')

def read_file(name,mode='r'):
	with open(name,mode) as f:
		text = f.readlines()

	return text





import requests 



class SetCode:

	def __init__(self,repo=None,filename=None,user="rishabh-creator601",branch='main',newfilename=None,mode='wb'):

		self.user = user
		self.branch = branch
		self.repo = repo
		self.filename = filename 


		self.url = f"https://raw.githubusercontent.com/{self.user}/{self.repo}/{self.branch}/{self.filename}"

		self.start(repo,filename,user,branch,newfilename,mode)


	def start(self,repo,filename,user="rishabh-creator601",branch='main',newfilename=None,mode='wb'):
		if newfilename is not None:
			newfilename = newfilename
		else:
			newfilename = filename





		cont = requests.get(self.url)



		with open(newfilename,mode) as f:
			f.write(cont.content)
		f.close()

		print('File {} Loaded '.format(newfilename))






if __name__ == '__main__':
	SetCode(filename="data.json",repo="codes")





from setuptools import setup ,find_packages



setup(

name = "pycosmic",
version="3.3.0",
description="Packages That Shortens The Code  ",
author="Rishabh",
author_email="rishivisionworld@gmail.com",
install_requires=['qrcode','opencv-python'],
packages=find_packages(),


)


import numpy as np

def add_mat(a,b):
	if a.shape != b.shape:
		print("Shape Must Be Equal ")
	else:
		matrix = np.zeros(a.shape)
		for row in range(a.shape[0]):
			for col in range(a.shape[1]):
				matrix[row][col] = a[row][col] + b[row][col]

		return matrix



def sub_mat(a,b):
	if a.shape != b.shape:
		print("Shape Must Be Equal ")
	else:
		matrix = np.zeros(a.shape)
		for row in range(a.shape[0]):
			for col in range(a.shape[1]):
				matrix[row][col] = a[row][col] - b[row][col]

		return matrix



def mul(matrix,val):
	for row in range(matrix.shape[0]):
		for col in range(matrix.shape[1]):
			matrix[row][col] *= val 
	return matrix


